import { AdminUtils } from '$lib/server/admin-utils';
import { Changesets } from '$lib/server/changesets';
import { IPAddressesAdmin } from '$lib/server/ip/admin';
import { IPAddresses } from '$lib/server/ip/index.js';
import { hasPrivileges } from '$lib/utils.js';

const PAGE_SIZE = 100;

export const load = async ({ parent, url }) => {
	const { user } = await parent();
	AdminUtils.checkPrivileges(user, ['admin:ip']);

	const {
		page,
		pageSize,
		ip,
		flags,
		user: listUser,
		listId
	} = Changesets.only(['page', 'pageSize', 'user', 'flags', 'ip', 'listId'], url.searchParams);

	const limit = Number(pageSize) || PAGE_SIZE;
	const offset = ((Number(page) || 1) - 1) * limit;

	const data = await IPAddressesAdmin.filterSearchIpAddresses({
		limit,
		offset,
		ip,
		includeUsers: !!ip && hasPrivileges(user.privileges, ['admin:user']),
		user: listUser,
		flags: flags ? Number(flags) : undefined,
		listId: listId ? Number(listId) : undefined
	});

	return {
		...data,
		flags: IPAddresses.flagsList
	};
};
